#######################
Development & community
#######################

django CMS is an open-source project, and relies on its community of users to
keep getting better.

The contributors to django CMS come from across the world, and have
a wide range and levels of skills and expertise. Every contribution,
however small, is valued.

As an open source project, anyone is welcome to contribute in whatever form
they are able, which can include taking part in discussions, filing bug reports,
proposing improvements, contributing code or documentation, and testing the


.. toctree::
    :maxdepth: 1

    development-community
    development-policies
    code
    documentation
    translations
    management
    testing
    code_of_conduct
